@@ -23,10 +23,11 @@ use Fatal qw( open close pipe fcntl );
 use Class::Struct;
 use IO::Handle;
 
+use Math::BigInt try => 'GMP';
 use GnuPG::Options;
 use GnuPG::Handles;
 
-$VERSION = '0.42_01';
+$VERSION = '0.42_02';
 
 has $_ => (
     isa     => 'Any',
@@ -381,6 +382,7 @@ sub get_keys {
         '--fixed-list-mode',
         '--with-fingerprint',
         '--with-fingerprint',
+        '--with-key-data',
     );
 
     my $stdin  = IO::Handle->new();
@@ -586,6 +588,10 @@ sub get_keys {
           # revokers should be bound to the key with signatures:
           $current_signed_item = $rvk;
         }
+        elsif ($record_type eq 'pkd') {
+          my ($pos, $size, $data) = @fields[ 1,2,3 ];
+          $current_key->pubkey_data->[$pos+0] = Math::BigInt->from_hex('0x'.$data);
+        }
         elsif ( $record_type ne 'tru' ) {
             warn "unknown record type $record_type";
         }
